@@ -5,7 +5,11 @@ import threading
 import time
 
 import numpy as np
-from loguru import logger as logging
+from jinja2.nodes import NodeType
+
+from scopinator.seestar.commands.parameterized import IscopeStartView, IscopeStartViewParams, ScopeViewMode
+from scopinator.util.logging_config import get_logger
+logging = get_logger(__name__)
 from pydantic import BaseModel
 
 from scopinator.seestar.commands.imaging import (
@@ -19,7 +23,7 @@ from scopinator.seestar.events import (
     EventTypes,
     AnnotateResult,
     BaseEvent,
-    InternalEvent,
+    InternalEvent, ModeType,
 )
 from scopinator.seestar.protocol_handlers import BinaryProtocol, ScopeImage
 from scopinator.seestar.rtspclient import RtspClient
@@ -43,6 +47,7 @@ class SeestarImagingStatus(BaseModel):
     is_streaming: bool = False
     is_fetching_images: bool = False
     is_receiving_image: bool = False  # True while receiving image data
+    is_sending_image: bool = False
     
     # Image retrieval timing
     last_image_start_time: float | None = None  # Timestamp when image started being received (milliseconds)
@@ -64,6 +69,7 @@ class SeestarImagingStatus(BaseModel):
         self.is_streaming = False
         self.is_fetching_images = False
         self.is_receiving_image = False
+        self.is_sending_image = False
         # Reset timing fields
         self.last_image_start_time = None
         self.last_image_end_time = None
@@ -95,10 +101,6 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
     image: ScopeImage | None = None
     client_mode: Literal["ContinuousExposure", "Stack", "Streaming"] | None = None
     
-    # Raw image caching for instant processing
-    cached_raw_image: Optional[ScopeImage] = None
-    cached_raw_image_lock: threading.Lock = threading.Lock()
-    cached_raw_image_timestamp: float = 0.0
     enhancement_settings_changed_event: Optional[asyncio.Event] = None
 
     # Timeout configuration
@@ -122,6 +124,11 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
         read_timeout: float = 30.0,
         write_timeout: float = 10.0,
     ):
+        # Create an EventBus if none provided
+        if event_bus is None:
+            from scopinator.util.eventbus import EventBus
+            event_bus = EventBus()
+            
         super().__init__(
             host=host,
             port=port,
@@ -182,10 +189,21 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
                     
                     data = await self.connection.read_exactly(size)
                     if data is None:
-                        logging.warning(f"Issue while reading image data for {self}")
-                        # Connection issue during data read, continue
+                        logging.info(f"Connection interrupted while reading image data from {self.host}:{self.port}")
+                        # Connection was reset and reconnected, need to restart streaming
                         self.status.is_receiving_image = False
-                        await asyncio.sleep(0.1)
+                        
+                        # If we were streaming, try to restart it
+                        if self.status.is_streaming:
+                            logging.info(f"Restarting streaming after reconnection for {self.host}:{self.port}")
+                            try:
+                                # Send BeginStreaming command again
+                                _ = await self.send(BeginStreaming(id=21))
+                                logging.debug(f"Streaming restarted successfully for {self.host}:{self.port}")
+                            except Exception as e:
+                                logging.debug(f"Failed to restart streaming: {e}")
+                        
+                        await asyncio.sleep(0.5)  # Give it a moment to stabilize
                         continue
 
                 # print(f"Data: {data is not None} Size: {size}")
@@ -224,18 +242,10 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
                             self.status.avg_image_elapsed_ms = sum(self._image_timing_history) / len(self._image_timing_history)
                         
                         logging.debug(f"Image received in {elapsed_ms:.1f}ms (avg: {self.status.avg_image_elapsed_ms:.1f}ms, size: {size} bytes)")
-                    
-                    # Cache the raw image for instant processing
-                    # Only cache if we have valid image data (both the ScopeImage and its image field)
-                    # print(f"Image {self.image is not None} image image: {self.image.image is not None if self.image is not None else None}")
-                    if self.image is not None and self.image.image is not None:
-                        with self.cached_raw_image_lock:
-                            self.cached_raw_image = self.image.copy() if hasattr(self.image, 'copy') else self.image
-                            self.cached_raw_image_timestamp = time.time()
 
             except Exception as e:
-                logging.error(
-                    f"Unexpected error in imaging reader task for {self}: {e}"
+                logging.info(
+                    f"Imaging reader task error for {self.host}:{self.port}: {type(e).__name__}"
                 )
                 self.status.is_receiving_image = False
                 if self.is_connected:
@@ -332,14 +342,6 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
         self.status.is_fetching_images = True
         try:
             while self.is_connected:
-                # Check if enhancement settings changed and we have a cached image
-                # if self.enhancement_settings_changed_event.is_set():
-                #     self.enhancement_settings_changed_event.clear()
-                #     with self.cached_raw_image_lock:
-                #         if self.cached_raw_image is not None:
-                #             logging.info("Enhancement settings changed, yielding cached image for instant processing")
-                #             yield self.cached_raw_image
-                #             continue
                 if self.client_mode == "Streaming":
                     # If we're streaming, just run RTSP client, which runs as a background thread...
                     rtsp_port = 4554 + camera_id
@@ -353,24 +355,51 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
                                 width=1080, height=1920, image=rtsp_client.read()
                             )
 
-                            if image is not None:
-                                changed = not np.array_equal(
-                                    self.image.image, last_image.image
-                                )
-                                last_image = image
-
+                            if image is not None and image.image is not None:
+                                # Check if image has changed from the last one we sent
+                                if last_image.image is not None:
+                                    changed = not np.array_equal(
+                                        image.image, last_image.image
+                                    )
+                                else:
+                                    # First image, always consider it as changed
+                                    changed = True
+                                
                                 if changed:
+                                    last_image = image
+                                    self.image = image  # Update current image
+                                    self.status.is_sending_image = True
                                     yield image
+                                    self.status.is_sending_image = False
                             await asyncio.sleep(0)
 
                     await asyncio.sleep(0.5)
                     continue
 
-                if self.image is not None:
-                    last_image = self.image
+                if self.image is not None and self.image.image is not None:
+                    # Check if image has changed from the last one we sent
+                    if last_image.image is not None:
+                        changed = not np.array_equal(
+                            self.image.image, last_image.image
+                        )
+                    else:
+                        # First image, always consider it as changed
+                        changed = True
 
-                    logging.trace(f"Image changed, yielding image for {self}")
-                    yield self.image
+                    if changed:
+                        logging.debug(f"Image changed, yielding image for {self}")
+                        last_image = self.image
+                        # self.image = image  # Update current image
+                        self.status.is_sending_image = True
+                        yield self.image
+                        self.status.is_sending_image = False
+
+                    # last_image = self.image
+
+                    # logging.trace(f"Image changed, yielding image for {self}")
+                    # self.status.is_sending_image = True
+                    # yield self.image
+                    # self.status.is_sending_image = False
                 await asyncio.sleep(0.1)
         except Exception as e:
             logging.error(f"Unexpected error in imaging reader task for {self}: {e}")
@@ -378,6 +407,7 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
 
             traceback.print_exc()
 
+        self.status.is_sending_image = False
         self.status.is_fetching_images = False
 
     async def _handle_stack_event(self, event: BaseEvent):
@@ -489,10 +519,10 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
             self.enhancement_settings_changed_event.set()
             logging.info("Enhancement settings changed event triggered")
     
-    def get_cached_raw_image(self) -> Optional[ScopeImage]:
-        """Get the cached raw image."""
-        with self.cached_raw_image_lock:
-            return self.cached_raw_image.copy() if self.cached_raw_image and hasattr(self.cached_raw_image, 'copy') else self.cached_raw_image
+    # def get_cached_raw_image(self) -> Optional[ScopeImage]:
+    #     """Get the cached raw image."""
+    #     with self.cached_raw_image_lock:
+    #         return self.cached_raw_image.copy() if self.cached_raw_image and hasattr(self.cached_raw_image, 'copy') else self.cached_raw_image
 
     async def _connection_monitor(self):
         """Background task that monitors connection health and manages reconnection."""
@@ -528,13 +558,22 @@ class SeestarImagingClient(BaseModel, arbitrary_types_allowed=True):
                             # Restart the reader task after successful reconnection
                             self.reader_task = asyncio.create_task(self._reader())
                             logging.info(f"Connection monitor successfully reconnected {self} and restarted reader task")
+                            
+                            # If we were streaming, restart it
+                            if self.status.is_streaming:
+                                logging.debug(f"Restarting streaming after connection monitor reconnection")
+                                try:
+                                    await self.send(BeginStreaming(id=21))
+                                    logging.debug(f"Streaming restarted by connection monitor")
+                                except Exception as e:
+                                    logging.debug(f"Connection monitor failed to restart streaming: {e}")
                         except Exception as e:
-                            logging.warning(f"Connection monitor failed to reconnect {self}: {e}")
+                            logging.debug(f"Connection monitor failed to reconnect {self.host}:{self.port}: {type(e).__name__}")
                         finally:
                             self._reconnect_in_progress = False
                             
             except Exception as e:
-                logging.error(f"Error in connection monitor task for {self}: {e}")
+                logging.debug(f"Error in connection monitor task for {self.host}:{self.port}: {type(e).__name__}")
                 await asyncio.sleep(5.0)  # Wait before retrying
                 
         logging.debug(f"Connection monitor task stopped for {self}")
